@@ -80,13 +80,15 @@ Ratchet <- function (tree, dataset,
                      searchIter = 4000, searchHits = 42,
                      bootstrapIter = searchIter, bootstrapHits = searchHits,
                      verbosity = 1L, 
-                     suboptimal = sqrt(.Machine$double.eps), ...) {
+                     suboptimal = sqrt(.Machine[["double.eps"]]), ...) {
   epsilon <- 1e-08
   hits <- 0L
   # initialize tree and data
-  if (dim(tree$edge)[1] != 2 * tree$Nnode) stop("tree must be bifurcating; try rooting with ape::root")
+  if (dim(tree[["edge"]])[1] != 2 * tree[["Nnode"]]) {
+    stop("tree must be bifurcating; try rooting with ape::root")
+  }
   tree <- RenumberTips(tree, names(dataset))
-  edgeList <- tree$edge
+  edgeList <- tree[["edge"]]
   edgeList <- RenumberEdges(edgeList[, 1], edgeList[, 2])
 
   initializedData <- InitializeData(dataset)
@@ -202,7 +204,7 @@ Ratchet <- function (tree, dataset,
     if (length(forest) > 1) {
       forest[] <- lapply(forest, function (phy) {
         x <- tree
-        x$edge <- cbind(phy[[1]], phy[[2]])
+        x[["edge"]] <- cbind(phy[[1]], phy[[2]])
         attr(x, "score") <- phy[[3]]
         # Return to lapply: 
         x})
@@ -214,7 +216,7 @@ Ratchet <- function (tree, dataset,
     } else if (length(forest) == 1) {
       ret <- tree
       newEdge <- forest[[1]]
-      ret$edge <- cbind(newEdge[[1]], newEdge[[2]])
+      ret[["edge"]] <- cbind(newEdge[[1]], newEdge[[2]])
       uniqueScores <- newEdge[[3]]
     } else {
       stop("\nNo trees!? Is suboptimal set to a sensible (positive) value?")
@@ -228,10 +230,10 @@ Ratchet <- function (tree, dataset,
     # Return:
     ret
   } else {
-    tree$edge <- cbind(edgeList[[1]], edgeList[[2]])
+    tree[["edge"]] <- cbind(edgeList[[1]], edgeList[[2]])
     attr(tree, "score") <- bestScore
     # Return:
-    tree  
+    tree
   }
 }
 
