@@ -57,10 +57,14 @@ TBR <- function(tree, edgeToBreak = NULL, mergeEdges = NULL) {
     }
   }
   
-  edge <- tree[["edge"]]  
+  edge <- tree[["edge"]]
   StopUnlessBifurcating(edge[, 1])
-  newEdge <- TBRSwap(edge[, 1], edge[, 2], edgeToBreak = edgeToBreak,
-                     mergeEdges = mergeEdges)
+  newEdge <- TBRSwap(
+    parent = edge[, 1],
+    child = edge[, 2],
+    edgeToBreak = edgeToBreak,
+    mergeEdges = mergeEdges
+  )
   tree[["edge"]] <- cbind(newEdge[[1]], newEdge[[2]])
   tree
 }
@@ -98,47 +102,67 @@ TBRMoves.matrix <- function (tree, edgeToBreak = integer(0)) {
 #' @template treeParent
 #' @template treeChild
 #' @param nEdge (optional) Number of edges.
-#' @return a list containing two elements, corresponding in turn to the
-#'  rearranged parent and child parameters
+#' @return `TBRSwap()` returns a list containing two elements corresponding
+#' to the rearranged `parent` and `child` parameters.
 #'  
 #' @importFrom TreeTools EdgeAncestry
 #' @export
-TBRSwap <- function(parent, child, nEdge = length(parent), 
+TBRSwap <- function(parent, child, nEdge = length(parent),
                     edgeToBreak = NULL,
                     mergeEdges = NULL) {
-  if (nEdge < 5) return (list(parent, child)) #TODO do we need to re-root this tree?
+  if (nEdge < 5) {
+    return (list(parent, child)) #TODO do we need to re-root this tree?
+  }
   
   # Pick an edge at random
   allEdges <- seq_len(nEdge - 1L) + 1L # Only include one root edge
   not1 <- !logical(nEdge)
-  not1[1] <- FALSE
+  not1[[1]] <- FALSE
   if (is.null(edgeToBreak)) {
-    edgeToBreak <- SampleOne(allEdges, len=nEdge - 1L)
+    edgeToBreak <- SampleOne(allEdges, len = nEdge - 1L)
   } else {
-    if (edgeToBreak > nEdge) return(TBRWarning(parent, child, "edgeToBreak > nEdge"))
-    if (edgeToBreak < 1) return(TBRWarning(parent, child, "edgeToBreak < 1"))
-    if (edgeToBreak == 1) edgeToBreak <- which(parent == parent[1])[-1] # Use other side of root
+    if (edgeToBreak > nEdge) {
+      return(TBRWarning(parent, child, "edgeToBreak > nEdge"))
+    }
+    if (edgeToBreak < 1) {
+      return(TBRWarning(parent, child, "edgeToBreak < 1"))
+    }
+    if (edgeToBreak == 1) {
+      edgeToBreak <- which(parent == parent[[1]])[-1] # Use other side of root
+    }
   }
+  # More efficient than tabulate or c(logical(), TRUE, logical())
   brokenEdge <- seq_along(parent) == edgeToBreak
+  
   brokenEdge.parentNode <- parent[edgeToBreak]
   brokenEdge.childNode  <-  child[edgeToBreak]
   
   if (!is.null(mergeEdges)) { # Quick sanity checks
-    if (any(mergeEdges > nEdge)) return(TBRWarning(parent, child, "mergeEdges value > number of edges"))
-    if (length(mergeEdges) > 2 || length(mergeEdges) == 0) 
-      return(TBRWarning(parent, child, paste0("mergeEdges value ", paste(mergeEdges, collapse="|"),  
-                                              " invalid; must be NULL or a vector of length 1 or 2\n  ")))
-    if (length(mergeEdges) == 2 && mergeEdges[1] == mergeEdges[2]) 
+    if (any(mergeEdges > nEdge)) {
+      return(TBRWarning(parent, child, "mergeEdges value > number of edges"))
+    } else if (length(mergeEdges) > 2 || length(mergeEdges) == 0) {
+      return(TBRWarning(
+        parent, child,
+        paste0("mergeEdges value ", paste(mergeEdges, collapse = "|"),
+               " invalid; must be NULL or a vector of length 1 or 2\n  ")
+      ))
+    } else if (length(mergeEdges) == 2 && mergeEdges[1] == mergeEdges[2]) {
       return(TBRWarning(parent, child, "mergeEdges values must differ"))
+    }
   }
   
-  edgesCutAdrift <- DescendantEdges(edge = edgeToBreak, parent, child, nEdge)
+  edgesCutAdrift <- DescendantEdges(edge = edgeToBreak, parent = parent,
+                                    child = child, nEdge = nEdge)
   edgesRemaining <- !edgesCutAdrift & !brokenEdge
   
   brokenEdgeParent <- child == brokenEdge.parentNode
   brokenEdgeSister <- parent == brokenEdge.parentNode & !brokenEdge
   brokenEdgeDaughters <- parent == brokenEdge.childNode
-  nearBrokenEdge <- brokenEdge | brokenEdgeSister | brokenEdgeParent | brokenEdgeDaughters
+  nearBrokenEdge <- brokenEdge | 
+    brokenEdgeSister | 
+    brokenEdgeParent | 
+    brokenEdgeDaughters
+  
   if (breakingRootEdge <- !any(brokenEdgeParent)) { 
     # Edge to break is the Root Node.
     brokenRootDaughters <- parent == child[brokenEdgeSister]
@@ -148,20 +172,35 @@ TBRSwap <- function(parent, child, nEdge = length(parent),
   if (is.null(mergeEdges)) {
     candidateEdges <- which(!nearBrokenEdge & not1)
     nCandidates <- length(candidateEdges)
-    if (nCandidates > 1) mergeEdges <- SampleOne(candidateEdges, len=nCandidates) else mergeEdges <- candidateEdges
+    mergeEdges <- if (nCandidates > 1) {
+      SampleOne(candidateEdges, len = nCandidates) 
+    } else {
+      candidateEdges
+    }
   }
   if (length(mergeEdges) == 1) {
-    if (edgesCutAdrift[mergeEdges]) {
+    if (edgesCutAdrift[[mergeEdges]]) {
       adriftReconnectionEdge <- mergeEdges
-      if (nearBrokenEdge[mergeEdges]) {
+      if (nearBrokenEdge[[mergeEdges]]) {
         samplable <- which(!edgesCutAdrift & !nearBrokenEdge & not1)
       } else {
         samplable <- which(!edgesCutAdrift & not1)
-        if (all(edgesCutAdrift == not1) && breakingRootEdge) samplable <- 1
+        if (all(edgesCutAdrift == not1) && breakingRootEdge) {
+          samplable <- 1
+        }
       }
       nSamplable <- length(samplable)
-      if (nSamplable == 0) return(TBRWarning(parent, child, "No reconnection site would modify the tree; check mergeEdge"))
-      rootedReconnectionEdge <- if (nSamplable == 1) samplable else SampleOne(samplable, len=nSamplable)
+      if (nSamplable == 0) {
+        return(TBRWarning(
+          parent, child,
+          "No reconnection site would modify the tree; check mergeEdge"
+        ))
+      }
+      rootedReconnectionEdge <- if (nSamplable == 1) {
+        samplable
+      } else {
+        SampleOne(samplable, len = nSamplable)
+      }
       #### message(" - Selected rooted Reconnection Edge: ", rootedReconnectionEdge, "\n")  #### DEBUGGING AID
     } else {
       rootedReconnectionEdge <- mergeEdges
@@ -171,24 +210,44 @@ TBRSwap <- function(parent, child, nEdge = length(parent),
         samplable <- which(edgesCutAdrift & not1)
       }
       nSamplable <- length(samplable)
-      if (nSamplable == 0) return(TBRWarning(parent, child, "No reconnection site would modify the tree; check mergeEdge"))
-      adriftReconnectionEdge <- if (nSamplable == 1) samplable else SampleOne(samplable)
+      if (nSamplable == 0) {
+        return(TBRWarning(
+          parent, child,
+          "No reconnection site would modify the tree; check mergeEdge"
+        ))
+      }
+      adriftReconnectionEdge <- if (nSamplable == 1) {
+        samplable
+      } else {
+        SampleOne(samplable)
+      }
       #### message(" - Selected adrift Reconnection Edge: ", adriftReconnectionEdge, "\n") #### DEBUGGING AID
     }
   } else {
     whichAdrift <- edgesCutAdrift[mergeEdges]
-    if (sum(whichAdrift) != 1) return(TBRWarning(parent, child, paste("Invalid edges selected to merge:", mergeEdges[1], mergeEdges[2])))
+    if (sum(whichAdrift) != 1) {
+      return(TBRWarning(
+        parent, child,
+        paste("Invalid edges selected to merge:",
+              mergeEdges[[1]], mergeEdges[[2]])
+      ))
+    }
     adriftReconnectionEdge <- mergeEdges[whichAdrift]
     rootedReconnectionEdge <- mergeEdges[!whichAdrift]
   }
-  if(nearBrokenEdge[rootedReconnectionEdge] && nearBrokenEdge[adriftReconnectionEdge]) 
-    return(TBRWarning(parent, child, "Selected mergeEdges will not change tree topology."))
+  if(nearBrokenEdge[rootedReconnectionEdge] &&
+     nearBrokenEdge[adriftReconnectionEdge]) {
+    return(TBRWarning(
+      parent, child, "Selected mergeEdges will not change tree topology."
+    ))
+  }
   #### edgelabels(edge = edgeToBreak, bg="orange", cex=1.8)  #### DEBUGGING AID
   #### edgelabels(edge=adriftReconnectionEdge, bg="cyan")    #### DEBUGGING AID
   #### edgelabels(edge=rootedReconnectionEdge, bg="magenta") #### DEBUGGING AID
   
-  if (!nearBrokenEdge[adriftReconnectionEdge]) {
-    edgesToInvert <- EdgeAncestry(adriftReconnectionEdge, parent, child, stopAt = edgeToBreak) & !brokenEdge
+  if (!nearBrokenEdge[[adriftReconnectionEdge]]) {
+    edgesToInvert <- EdgeAncestry(adriftReconnectionEdge, parent, child,
+                                  stopAt = edgeToBreak) & !brokenEdge
     #### which(edgesToInvert)
     if (any(edgesToInvert)) {
       tmp <- parent[edgesToInvert]
@@ -206,7 +265,7 @@ TBRSwap <- function(parent, child, nEdge = length(parent),
     child[repurposedDaughterEdge] <- child[spareDaughterEdge]
     child[spareDaughterEdge] <- parent[adriftReconnectionEdge]
     #########Assert(parent[spareDaughterEdge] == brokenEdge.childNode)
-    parent[adriftReconnectionEdge] <- brokenEdge.childNode
+    parent[[adriftReconnectionEdge]] <- brokenEdge.childNode
   }
   if (!nearBrokenEdge[rootedReconnectionEdge]) {
     if (breakingRootEdge) {
@@ -224,7 +283,8 @@ TBRSwap <- function(parent, child, nEdge = length(parent),
   
   #########Assert(identical(unique(table(parent)), 2L))
   #########Assert(identical(unique(table(child)),  1L))
-  return (RenumberEdges(parent, child))
+  # Return:
+  RenumberEdges(parent, child)
 }
 
 #' Rooted TBR 
@@ -251,7 +311,7 @@ RootedTBRSwap <- function (parent, child, nEdge=length(parent),
   nTips <- (nEdge / 2L) + 1L
   rootNode <- parent[1]
   rootEdges <- parent == rootNode
-  rightTree <- DescendantEdges(parent, child, edge = 1, nEdge)
+  rightTree <- DescendantEdges(parent, child, edge = 1, nEdge = nEdge)
   selectableEdges <- !rootEdges
   if (sum( rightTree) < 4) {
     selectableEdges[ rightTree] <- FALSE
@@ -287,8 +347,9 @@ RootedTBRSwap <- function (parent, child, nEdge=length(parent),
     edgeInRight <- rightTree[edgeToBreak]
     subtreeWithRoot <- if (edgeInRight) rightTree else !rightTree
     subtreeEdges <- !rootEdges & subtreeWithRoot
-    if (sum(edgesCutAdrift <- DescendantEdges(parent, child, edge = edgeToBreak,
-                                              nEdge)) > 2) {
+    edgesCutAdrift <- DescendantEdges(parent, child, edge = edgeToBreak,
+                                      nEdge = nEdge)
+    if (sum(edgesCutAdrift) > 2) {
       break;
     }
     if (sum(subtreeEdges, -edgesCutAdrift) > 2) {
